############
Explanations
############

This page will summarize additional explanatory content.

.. toctree::
   :maxdepth: 1
   :glob:

   introduction
   projective_measurement
   randomization
   frame

